summaryrefslogtreecommitdiff
path: root/src/table/palettes.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/table/palettes.h')
-rw-r--r--src/table/palettes.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/table/palettes.h b/src/table/palettes.h
index 98a9baefc..6a3320ec5 100644
--- a/src/table/palettes.h
+++ b/src/table/palettes.h
@@ -194,13 +194,13 @@ static const ExtraPaletteValues _extra_palette_values = {
};
#undef M
-// Color table for colors in lang files (e.g. {BLACK})
-struct StringColor {
+// Colour table for colours in lang files (e.g. {BLACK})
+struct StringColour {
byte text;
byte shadow;
};
-static const StringColor _string_colourmap[][17] = {
+static const StringColour _string_colourmap[][17] = {
{ /* DOS palette. */
{ 150, 1 }, // TC_BLUE
{ 12, 1 }, // TC_SILVER